@@ -22,7 +22,6 @@
 use strict;
 use Getopt::Long;
 use Pod::Usage qw(pod2usage);
-use File::Slurp qw(write_file);
 use Geo::BUFR;
 
 # Will be used if neither --tablepath nor $ENV{BUFR_TABLES} is set
@@ -85,14 +84,17 @@ my ($data_refs, $desc_refs, $num_subsets) = readdata($data_file);
 $bufr->set_number_of_subsets($num_subsets);
 
 # Print the encoded BUFR message
+my $buffer = $bufr->encode_message($data_refs, $desc_refs);
 if ($option{outfile}) {
-    my $buffer = $bufr->encode_message($data_refs, $desc_refs);
-    write_file($option{outfile}, {binmode => ':raw'}, $buffer);
+    my $outfile = $option{outfile};
+    open my $fh, '>', $outfile or die "Can't open $outfile: $!";
+    binmode($fh);
+    print $fh $buffer;
 } else {
-    print $bufr->encode_message($data_refs, $desc_refs);
+    binmode(STDOUT);
+    print $buffer;
 }
 
-
 # See OPTIONS section in pod for format of metadata file
 sub read_metadata {
     my ($file, $bufr) = @_;
